API
==============================================================================

Preprocessing
---------------------
.. automodule:: vipcca.preprocessing.preprocessing
   :members: 
   :undoc-members:
   :show-inheritance:


VIPCCA
---------------------

.. automodule:: vipcca.vipcca
   :members:
   :undoc-members:
   :show-inheritance:
